.. Dioptas documentation master file, created by
   sphinx-quickstart on Wed Jul 19 16:41:31 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

===================================
Welcome to Dioptas's documentation!
===================================

.. toctree::
   :maxdepth: 2

   introduction
   calibration
   mask
   integration
   configurations_and_projects